==> western-world-3.0.411.tgz: package/src/defs/buy.js <==
export const buy = `
<symbol id="buy" viewBox="0 0 8192 8192">
<style type="text/css">
	.buy_st0{fill:#EB876C;}
	.buy_st1{fill:#7D5052;}
	.buy_st2{fill:#1A9BAB;}
	.buy_st3{fill:none;stroke:#FFFFFF;stroke-width:30;stroke-miterlimit:10;}
	.buy_st4{fill:#07FF00;}
	.buy_st5{fill:#FFB512;}
	.buy_st6{fill:#FFFFFF;}
</style>
<g id="buy-main-container">
	<g id="hand_1">
		<path class="buy_st0" d="M3523.3,4534.7l-6459.2,515.4l99.7,1909.7l6469.5-949.2C3633.3,6010.6,4675.1,5107.7,3523.3,4534.7z"/>
	</g>
	<g id="hand_2">
		<path class="buy_st1" d="M11186.8,4222.2L4695.4,4487c0,0-503.5,143.2-538.3,742.3c-34.7,599,344.4,717.7,344.4,717.7l6593.1,538.7
			L11186.8,4222.2z"/>
	</g>
	<g id="hand_and_hand">
		<path class="buy_st0" d="M4181.2,4179.7c0,0-167.5-116.3-400.7-98.6c-200.8,15.2-491.6,429.7-491.6,1087.4
			c0,616.7-56.4,811.7,581.7,1024.4s1128.6,257.6,1163.4,162.1c34.7-95.5-121.5-130.2-121.5-130.2s552.2,53,596.1-69.5
			c44-122.5-144.7-217-144.7-217s179.4,57.9,217-14.5s-208.4-295.2-350.2-344.4c0,0,191,60.8,211.3-2.9
			c20.3-63.7-295.2-356-607.7-552.7c-312.5-196.8-775.6-483.3-775.6-483.3L4181.2,4179.7z"/>
		<path class="buy_st1" d="M3644.9,5724.1c-136-33.3-329.2,355.6-144.7,564.3c110,124.4,193.9,20.3,193.9,20.3s52.1,112.9,133.1,112.9
			c81,0,133.1-63.7,133.1-63.7s20.3,156.3,151.9,153.4c131.7-2.9,147.5-66.4,149-344.4c1.1-196.8-106.4-351.6-219.9-202.6
			c-50.1,65.8-50.6,90.1-50.6,90.1s-40.5-251.5-143.2-253.6c-69.5-1.4-111.4,96.9-111.4,96.9S3715.8,5741.5,3644.9,5724.1z"/>
		<path class="buy_st1" d="M4738.8,4658.4c0,0-17.4-180.1-208.4-316.9c-191-136.7-309-201.2-492.7-128.1
			c-245.3,97.7-689.4,685.1-514.4,822.6c121.5,95.5,525.2-327.7,525.2-327.7l240.2-14.5l341.5,201.1L4738.8,4658.4z"/>
	</g>
	<g id="message_2">
		<path class="buy_st2" d="M5191.2,2447.1h-784.4c0,0-788.9-86.3-788.9-953.8s865.1-910.6,1013-905.9c147.9,4.8,1290.9,0,1492.6,0
			s883,138.7,883,929.7s-654.4,930-874,930s-605.1,0-605.1,0s-65.9,738.5,209,1078.4c263.6,325.9,996.9,484.4,996.9,484.4
			s-992.1,0-1308.5-407.7C5147.6,3244.8,5191.2,2447.1,5191.2,2447.1z"/>
		<g id="stock">
			<path class="buy_st3" d="M5927.1,945.9h-950c0,0-19.4-188.4-174.8-188.4c-155.4,0-169,139.9-169,174.8c0,35,3.2,1020.2,3.2,1020.2
				s27.9-132.3,171.6-130.4s157.4,141.8,157.4,141.8h961.7c0,0,27.2,3.9,27.2-27.2s0-957.8,0-957.8S5958.2,945.9,5927.1,945.9z"/>
			<line class="buy_st3" x1="4977.1" y1="945.9" x2="4977.1" y2="1963.9"/>
			<path class="buy_st3" d="M4634.1,2009.1c0,0-10.7,172.4,206.9,172.4c204,0,973.3,0,973.3,0s40.8-0.7,44.7-54.8c3.9-54,0-153.1,0-153.1
				"/>
			<g id="text-placeholder">
				<line class="buy_st3" x1="5121.3" y1="1370.2" x2="5347.9" y2="1370.2"/>
				<line class="buy_st3" x1="5121.3" y1="1444.5" x2="5249.4" y2="1444.5"/>
				<line class="buy_st3" x1="5312.2" y1="1444.5" x2="5565.7" y2="1444.5"/>
				<line class="buy_st3" x1="5634.2" y1="1444.5" x2="5809.1" y2="1444.5"/>
				<line class="buy_st3" x1="5121.3" y1="1510.1" x2="5377.4" y2="1510.1"/>
				<line class="buy_st3" x1="5415.6" y1="1510.1" x2="5472.5" y2="1510.1"/>
				<line class="buy_st3" x1="5516.2" y1="1510.1" x2="5721.6" y2="1510.1"/>
				<line class="buy_st3" x1="5755.1" y1="1510.1" x2="5809.1" y2="1510.1"/>
				<line class="buy_st3" x1="5121.3" y1="1565.4" x2="5192.7" y2="1565.4"/>
				<line class="buy_st3" x1="5223.3" y1="1565.4" x2="5415.6" y2="1565.4"/>
				<line class="buy_st3" x1="5450.6" y1="1565.4" x2="5641.5" y2="1565.4"/>
				<line class="buy_st3" x1="5675" y1="1565.4" x2="5809.1" y2="1565.4"/>
				<line class="buy_st3" x1="5121.3" y1="1622.3" x2="5286" y2="1622.3"/>
				<line class="buy_st3" x1="5121.3" y1="1853.2" x2="5301.1" y2="1853.2"/>
			</g>
			<g id="logo">
				<path class="buy_st3" d="M5474.7,1030c-164.6,0-186.5,273.9,0,273.9S5645.1,1030,5474.7,1030z"/>
				<polyline class="buy_st3" points="5372.4,1078 5121.1,1078 5192,1166.9 5116.2,1258.7 5367.5,1258.7 			"/>
				<polyline class="buy_st3" points="5584.8,1078 5822.4,1078 5751.2,1159.5 5830.8,1258.7 5582.2,1258.7 			"/>
			</g>
			<path id="sign_2_" class="buy_st3" d="M5465.2,1660.2c0,0,11.7,176.8,29.1,210.8c17.5,34,44.7-88.4,60.2-87.4s18.5,88.4,31.6,89.4
				c13.1,1,28-96.2,40-96.2c12,0,17.8,95.9,54.2,98.2c29.6,1.9,36.4-33.2,70.4-33.2c34,0,50.2,37,96.2,37.1
				c36.9,0.1,48.6-14.1,48.6-14.1"/>
		</g>
	</g>
	<g id="message_1">
		<path class="buy_st5" d="M3011.1,3579.7h759.7c0,0,764-78.1,764-863.8s-837.8-824.8-981-820.4c-143.2,4.3-1250.2,0-1445.5,0
			c-195.3,0-855.2,125.6-855.2,842s633.8,842.3,846.5,842.3s586,0,586,0s65.1,291.5-169.3,543c-234.4,251.4-672.8,294.8-672.8,294.8
			s764,73.5,981-282.3C3041.5,3779.4,3011.1,3579.7,3011.1,3579.7z"/>
		<g id="dollar">
			<path class="buy_st6" d="M2456.2,2519.1v169.3c0,0,169.3,5.8,169.3,137.5s-147.6,137.5-147.6,137.5v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6
				c0-115.8,143.2-143.2,143.2-143.2v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1
				C2545.9,2501.7,2456.2,2519.1,2456.2,2519.1z M2327.4,2600.8c1.4,73.1,82.5,78.9,82.5,78.9v-162.1
				C2409.9,2517.6,2326,2527.8,2327.4,2600.8z M2463.4,2746.3V2917c0,0,104.2-14.5,104.2-98.4
				C2567.6,2752,2463.4,2746.3,2463.4,2746.3z"/>
			<path class="buy_st6" d="M2914.9,2529.2v169.3c0,0,169.3,5.8,169.3,137.5s-147.6,137.5-147.6,137.5v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6
				c0-115.8,143.2-143.2,143.2-143.2v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1
				C3004.6,2511.9,2914.9,2529.2,2914.9,2529.2z M2786.1,2611c1.4,73.1,82.5,78.9,82.5,78.9v-162.1
				C2868.6,2527.8,2784.6,2537.9,2786.1,2611z M2922.1,2756.4v170.7c0,0,104.2-14.5,104.2-98.4
				C3026.3,2762.2,2922.1,2756.4,2922.1,2756.4z"/>
			<path class="buy_st6" d="M3353.3,2540.8v169.3c0,0,169.3,5.8,169.3,137.5S3375,2985,3375,2985v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6s143.2-143.2,143.2-143.2
				v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1C3443,2523.4,3353.3,2540.8,3353.3,2540.8z M3224.5,2622.5
				c1.4,73.1,82.5,78.9,82.5,78.9v-162.1C3307,2539.3,3223.1,2549.5,3224.5,2622.5z M3360.5,2768v170.7c0,0,104.2-14.5,104.2-98.4
				C3464.7,2773.8,3360.5,2768,3360.5,2768z"/>
		</g>
	</g>
</g>
</symbol>
`;

==> western-world-3.0.439.tgz: package/src/defs/buy.js <==
export const buy = `
<symbol id="buy" viewBox="0 0 8192 8192">
<style type="text/css">
	.buy_st0{fill:#EB876C;}
	.buy_st1{fill:#7D5052;}
	.buy_st2{fill:#1A9BAB;}
	.buy_st3{fill:none;stroke:#FFFFFF;stroke-width:30;stroke-miterlimit:10;}
	.buy_st4{fill:#07FF00;}
	.buy_st5{fill:#FFB512;}
	.buy_st6{fill:#FFFFFF;}
</style>
<g id="buy-main-container">
	<g id="buy_hand_1">
		<path class="buy_st0" d="M3523.3,4534.7l-6459.2,515.4l99.7,1909.7l6469.5-949.2C3633.3,6010.6,4675.1,5107.7,3523.3,4534.7z"/>
	</g>
	<g id="buy_hand_2">
		<path class="buy_st1" d="M11186.8,4222.2L4695.4,4487c0,0-503.5,143.2-538.3,742.3c-34.7,599,344.4,717.7,344.4,717.7l6593.1,538.7
			L11186.8,4222.2z"/>
	</g>
	<g id="buy_hand_and_hand">
		<path class="buy_st0" d="M4181.2,4179.7c0,0-167.5-116.3-400.7-98.6c-200.8,15.2-491.6,429.7-491.6,1087.4
			c0,616.7-56.4,811.7,581.7,1024.4s1128.6,257.6,1163.4,162.1c34.7-95.5-121.5-130.2-121.5-130.2s552.2,53,596.1-69.5
			c44-122.5-144.7-217-144.7-217s179.4,57.9,217-14.5s-208.4-295.2-350.2-344.4c0,0,191,60.8,211.3-2.9
			c20.3-63.7-295.2-356-607.7-552.7c-312.5-196.8-775.6-483.3-775.6-483.3L4181.2,4179.7z"/>
		<path class="buy_st1" d="M3644.9,5724.1c-136-33.3-329.2,355.6-144.7,564.3c110,124.4,193.9,20.3,193.9,20.3s52.1,112.9,133.1,112.9
			c81,0,133.1-63.7,133.1-63.7s20.3,156.3,151.9,153.4c131.7-2.9,147.5-66.4,149-344.4c1.1-196.8-106.4-351.6-219.9-202.6
			c-50.1,65.8-50.6,90.1-50.6,90.1s-40.5-251.5-143.2-253.6c-69.5-1.4-111.4,96.9-111.4,96.9S3715.8,5741.5,3644.9,5724.1z"/>
		<path class="buy_st1" d="M4738.8,4658.4c0,0-17.4-180.1-208.4-316.9c-191-136.7-309-201.2-492.7-128.1
			c-245.3,97.7-689.4,685.1-514.4,822.6c121.5,95.5,525.2-327.7,525.2-327.7l240.2-14.5l341.5,201.1L4738.8,4658.4z"/>
	</g>
	<g id="buy_message_2">
		<path class="buy_st2" d="M5191.2,2447.1h-784.4c0,0-788.9-86.3-788.9-953.8s865.1-910.6,1013-905.9c147.9,4.8,1290.9,0,1492.6,0
			s883,138.7,883,929.7s-654.4,930-874,930s-605.1,0-605.1,0s-65.9,738.5,209,1078.4c263.6,325.9,996.9,484.4,996.9,484.4
			s-992.1,0-1308.5-407.7C5147.6,3244.8,5191.2,2447.1,5191.2,2447.1z"/>
		<g id="stock">
			<path class="buy_st3" d="M5927.1,945.9h-950c0,0-19.4-188.4-174.8-188.4c-155.4,0-169,139.9-169,174.8c0,35,3.2,1020.2,3.2,1020.2
				s27.9-132.3,171.6-130.4s157.4,141.8,157.4,141.8h961.7c0,0,27.2,3.9,27.2-27.2s0-957.8,0-957.8S5958.2,945.9,5927.1,945.9z"/>
			<line class="buy_st3" x1="4977.1" y1="945.9" x2="4977.1" y2="1963.9"/>
			<path class="buy_st3" d="M4634.1,2009.1c0,0-10.7,172.4,206.9,172.4c204,0,973.3,0,973.3,0s40.8-0.7,44.7-54.8c3.9-54,0-153.1,0-153.1
				"/>
			<g id="text-placeholder">
				<line class="buy_st3" x1="5121.3" y1="1370.2" x2="5347.9" y2="1370.2"/>
				<line class="buy_st3" x1="5121.3" y1="1444.5" x2="5249.4" y2="1444.5"/>
				<line class="buy_st3" x1="5312.2" y1="1444.5" x2="5565.7" y2="1444.5"/>
				<line class="buy_st3" x1="5634.2" y1="1444.5" x2="5809.1" y2="1444.5"/>
				<line class="buy_st3" x1="5121.3" y1="1510.1" x2="5377.4" y2="1510.1"/>
				<line class="buy_st3" x1="5415.6" y1="1510.1" x2="5472.5" y2="1510.1"/>
				<line class="buy_st3" x1="5516.2" y1="1510.1" x2="5721.6" y2="1510.1"/>
				<line class="buy_st3" x1="5755.1" y1="1510.1" x2="5809.1" y2="1510.1"/>
				<line class="buy_st3" x1="5121.3" y1="1565.4" x2="5192.7" y2="1565.4"/>
				<line class="buy_st3" x1="5223.3" y1="1565.4" x2="5415.6" y2="1565.4"/>
				<line class="buy_st3" x1="5450.6" y1="1565.4" x2="5641.5" y2="1565.4"/>
				<line class="buy_st3" x1="5675" y1="1565.4" x2="5809.1" y2="1565.4"/>
				<line class="buy_st3" x1="5121.3" y1="1622.3" x2="5286" y2="1622.3"/>
				<line class="buy_st3" x1="5121.3" y1="1853.2" x2="5301.1" y2="1853.2"/>
			</g>
			<g id="buy_logo">
				<path class="buy_st3" d="M5474.7,1030c-164.6,0-186.5,273.9,0,273.9S5645.1,1030,5474.7,1030z"/>
				<polyline class="buy_st3" points="5372.4,1078 5121.1,1078 5192,1166.9 5116.2,1258.7 5367.5,1258.7 			"/>
				<polyline class="buy_st3" points="5584.8,1078 5822.4,1078 5751.2,1159.5 5830.8,1258.7 5582.2,1258.7 			"/>
			</g>
			<path id="sign_2_" class="buy_st3" d="M5465.2,1660.2c0,0,11.7,176.8,29.1,210.8c17.5,34,44.7-88.4,60.2-87.4s18.5,88.4,31.6,89.4
				c13.1,1,28-96.2,40-96.2c12,0,17.8,95.9,54.2,98.2c29.6,1.9,36.4-33.2,70.4-33.2c34,0,50.2,37,96.2,37.1
				c36.9,0.1,48.6-14.1,48.6-14.1"/>
		</g>
	</g>
	<g id="buy_message_1">
		<path class="buy_st5" d="M3011.1,3579.7h759.7c0,0,764-78.1,764-863.8s-837.8-824.8-981-820.4c-143.2,4.3-1250.2,0-1445.5,0
			c-195.3,0-855.2,125.6-855.2,842s633.8,842.3,846.5,842.3s586,0,586,0s65.1,291.5-169.3,543c-234.4,251.4-672.8,294.8-672.8,294.8
			s764,73.5,981-282.3C3041.5,3779.4,3011.1,3579.7,3011.1,3579.7z"/>
		<g id="dollar">
			<path class="buy_st6" d="M2456.2,2519.1v169.3c0,0,169.3,5.8,169.3,137.5s-147.6,137.5-147.6,137.5v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6
				c0-115.8,143.2-143.2,143.2-143.2v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1
				C2545.9,2501.7,2456.2,2519.1,2456.2,2519.1z M2327.4,2600.8c1.4,73.1,82.5,78.9,82.5,78.9v-162.1
				C2409.9,2517.6,2326,2527.8,2327.4,2600.8z M2463.4,2746.3V2917c0,0,104.2-14.5,104.2-98.4
				C2567.6,2752,2463.4,2746.3,2463.4,2746.3z"/>
			<path class="buy_st6" d="M2914.9,2529.2v169.3c0,0,169.3,5.8,169.3,137.5s-147.6,137.5-147.6,137.5v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6
				c0-115.8,143.2-143.2,143.2-143.2v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1
				C3004.6,2511.9,2914.9,2529.2,2914.9,2529.2z M2786.1,2611c1.4,73.1,82.5,78.9,82.5,78.9v-162.1
				C2868.6,2527.8,2784.6,2537.9,2786.1,2611z M2922.1,2756.4v170.7c0,0,104.2-14.5,104.2-98.4
				C3026.3,2762.2,2922.1,2756.4,2922.1,2756.4z"/>
			<path class="buy_st6" d="M3353.3,2540.8v169.3c0,0,169.3,5.8,169.3,137.5S3375,2985,3375,2985v57.9h-52.1v-55
				c-149-2.9-160.6-124.4-160.6-124.4h62.2c7.2,63.7,89.7,73.8,89.7,73.8v-178c0,0-151.9-18.8-151.9-134.6s143.2-143.2,143.2-143.2
				v-59.3h43.4v63.7c154.8-1.4,162.1,128.8,162.1,128.8h-65.1C3443,2523.4,3353.3,2540.8,3353.3,2540.8z M3224.5,2622.5
				c1.4,73.1,82.5,78.9,82.5,78.9v-162.1C3307,2539.3,3223.1,2549.5,3224.5,2622.5z M3360.5,2768v170.7c0,0,104.2-14.5,104.2-98.4
				C3464.7,2773.8,3360.5,2768,3360.5,2768z"/>
		</g>
	</g>
</g>
</symbol>
`;
